function applyStyle(style) {
  const selection = window.getSelection();
  if (!selection.rangeCount) return;

  const range = selection.getRangeAt(0);
  const parentElement = selection.anchorNode.parentElement;

  // Verifica se o texto já possui o estilo
  if (parentElement.tagName === 'SPAN') {
    // Modifica o estilo existente
    if (style === 'bold') {
      parentElement.style.fontWeight =
        parentElement.style.fontWeight === 'bold' ? '' : 'bold';
    } else if (style === 'italic') {
      parentElement.style.fontStyle =
        parentElement.style.fontStyle === 'italic' ? '' : 'italic';
    } else if (style === 'underline') {
      parentElement.style.textDecoration =
        parentElement.style.textDecoration.includes('underline')
          ? parentElement.style.textDecoration.replace('underline', '').trim()
          : `${parentElement.style.textDecoration} underline`.trim();
    } else if (style === 'line-through') {
      parentElement.style.textDecoration =
        parentElement.style.textDecoration.includes('line-through')
          ? parentElement.style.textDecoration
              .replace('line-through', '')
              .trim()
          : `${parentElement.style.textDecoration} line-through`.trim();
    }

    // Remove o elemento <span> se nenhum estilo sobrar
    if (
      !parentElement.style.fontWeight &&
      !parentElement.style.fontStyle &&
      !parentElement.style.textDecoration.trim()
    ) {
      while (parentElement.firstChild) {
        parentElement.parentNode.insertBefore(
          parentElement.firstChild,
          parentElement,
        );
      }
      parentElement.remove();
    }
  } else {
    // Adiciona um novo <span> com o estilo aplicado
    const span = document.createElement('span');

    if (style === 'bold') {
      span.style.fontWeight = 'bold';
    } else if (style === 'italic') {
      span.style.fontStyle = 'italic';
    } else if (style === 'underline') {
      span.style.textDecoration = 'underline';
    } else if (style === 'line-through') {
      span.style.textDecoration = 'line-through';
    }

    range.surroundContents(span);
  }

  updateToolbarState();
}

function updateToolbarState() {
  const selection = window.getSelection();
  if (!selection.rangeCount) return;

  const parentElement = selection.anchorNode.parentElement;

  document
    .getElementById('bold-btn')
    .classList.toggle('active', parentElement.style.fontWeight === 'bold');
  document
    .getElementById('italic-btn')
    .classList.toggle('active', parentElement.style.fontStyle === 'italic');
  document
    .getElementById('underline-btn')
    .classList.toggle(
      'active',
      parentElement.style.textDecoration.includes('underline'),
    );
  document
    .getElementById('strike-btn')
    .classList.toggle(
      'active',
      parentElement.style.textDecoration.includes('line-through'),
    );
}

document.addEventListener('selectionchange', updateToolbarState);

const editor = document.getElementById('editor');
editor.addEventListener('focus', () => {
  if (editor.textContent === 'Digite aqui') {
    editor.textContent = '';
  }
});

editor.addEventListener('blur', () => {
  if (editor.textContent.trim() === '') {
    editor.textContent = 'Digite aqui';
  } else {
    document.querySelector('.texto-avisos').innerHTML = editor.innerHTML
  }

});
