document.querySelectorAll('.section').forEach((section) => {
  section.addEventListener('click', () => {
    // Alterna a classe 'active' na seção clicada
    const statusSection = !section.classList.contains('active'); // retorna true se tiver aberto
    document
      .querySelectorAll('.section')
      .forEach((elem) => elem.classList.remove('active'));

    if (statusSection) section.classList.add('active');
    else section.classList.remove('active');
  });
});

const btnStatusCart = document.querySelector('#btn-status-cart');
btnStatusCart.addEventListener('click', () => openListSelect(btnStatusCart));

const btnAlinhamento = document.querySelector('#btn-alinhamento-logo');
btnAlinhamento.addEventListener('click', () => openListSelect(btnAlinhamento));

const btnMinutosCron = document.querySelector('#btn-minutos-cronometro');
btnMinutosCron.addEventListener('click', () => openListSelect(btnMinutosCron));

function openListSelect(element) {
  const listValues = document.querySelectorAll('.list-values a');
  const elementSpan = element.querySelector('span');

  listValues.forEach((elem) => {
    if (elem.dataset.value == elementSpan.textContent) {
      elem.parentElement.classList.add('item-ativo');
    } else {
      elem.parentElement.classList.remove('item-ativo');
    }
  });
  element.parentElement.classList.toggle('ativo');
}

function changeValue(idElement, value) {
  const element = document.getElementById(idElement);
  const elementSpan = element.querySelector('span');

  elementSpan.textContent = value;
  element.parentElement.classList.remove('ativo');
  const alinhamentos = {
    Esquerda: 'space-beetween',
    Centro: 'center',
    Direita: 'right',
  };
  if (element.dataset.value)
    document.documentElement.style.setProperty(
      `${element.dataset.value}`,
      alinhamentos[value],
    );
}

const btnsResponsive = document.querySelectorAll('.btn-responsive');
const contentSite = document.querySelector('.content-site');
btnsResponsive.forEach((btn) => {
  btn.addEventListener('click', () => {
    const view = btn.dataset.view;
    const classL =
      view === 'mobile' ? 'content-site view-mobile' : 'content-site';

    contentSite.classList = classL;
  });
});

document.querySelector('.btn-sair-construtor').addEventListener('click', () => {
  window.history.back();
});

function getStore() {
  // pega o id da loja
  axios
    .get(
      'https://checkout-checkout-api.xwcabj.easypanel.host/store/getAllByUser',
      {
        headers: {
          Authorization: `Bearer ${localStorage.getItem(
            'authTokenVanillaCheckout',
          )}`,
          'Content-Type': 'application/json',
        },
      },
    )
    .then((response) => {
      localStorage.setItem('storeVanilla', response.data[0].id);
    })
    .catch((error) => {
      console.error(error);
    });
}

// getStore();

function saveData(configs) {
  fetch(
    'https://checkout-checkout-api.xwcabj.easypanel.host/store/updateSettings',
    {
      method: 'PUT', // Método HTTP
      headers: {
        Authorization: `Bearer ${localStorage.getItem(
          'authTokenVanillaCheckout',
        )}`,
        'Content-Type': 'application/json', // Tipo de conteúdo
      },
      body: JSON.stringify(configs), // Corpo da requisição
    },
  )
    .then((response) => {
      if (!response.ok) {
        throw new Error('Erro na requisição');
      }
      return response.json(); // Parse do JSON na resposta
    })
    .then((responseData) => {
      openAlert('alert-salvar-success');
      setTimeout(() => (window.location = '/personalizar.html'), 3000);
    })
    .catch((error) => {
      console.error('Erro:', error);
    });
}

function getData() {
  // puxa informações do personalizar
  fetch(
    `https://checkout-checkout-api.xwcabj.easypanel.host/store/getSettings`,
    {
      method: 'POST', // Método HTTP
      headers: {
        Authorization: `Bearer ${localStorage.getItem(
          'authTokenVanillaCheckout',
        )}`,
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ storeId: 1 }),
    },
  )
    .then((response) => {
      if (!response.ok) {
        throw new Error('Erro na requisição');
      }
      return response.json();
    })
    .then((responseData) => {
      customMenuPersonalizar(responseData);
      customPreview(responseData);
    })
    .catch((error) => {
      console.error('Erro:', error);
    });
}

getData();

function customMenuPersonalizar(data) {
  const alinhamentos = {
    'space-beetween': 'Esquerda',
    center: 'Centro',
    right: 'Direita',
  };

  document.querySelector('#btn-alinhamento-logo span').textContent =
    alinhamentos[data.alinhamento];

  document.querySelector('#btn-minutos-cronometro span').textContent =
    data.tempoCronometro + ' minutos';

  setColor(
    '--colorInputBarraAvisos',
    'text-color-input-barra-aviso',
    data.colorBarraAvisos,
  );
  setColor(
    '--bgColorInputBarraAvisos',
    'text-bgcolor-input-barra-aviso',
    data.backgroundColorBarraAvisos,
  );
  setColor(
    '--colorDesconto',
    'text-color-input-desconto',
    data.colorTextoDesconto,
  );
  setColor(
    '--colorTemporizador',
    'text-color-input-temporizador',
    data.colorTextoTemporizador,
  );
  document.querySelector('#btn-status-cart span').textContent =
    data.exibirCarrinho ? 'Sempre aberto' : 'Sempre fechado';

  setColor('--colorEtapas', 'text-color-input-etapas', data.colorEtapas);
  setColor(
    '--colorBotoesEtapas',
    'text-color-input-botoes-etapas',
    data.colorBtnsEtapas,
  );
  setColor(
    '--bgColorBotoesEtapas',
    'text-bgcolor-input-botoes-etapas',
    data.backgroundColorBtnsEtapas,
  );
  setColor(
    '--colorBotaoFinalizar',
    'text-color-input-botao-finalizar',
    data.colorBtnFinalizarCompra,
  );
  setColor(
    '--bgColorBotaoFinalizar',
    'text-bgcolor-input-botao-finalizar',
    data.backgroundColorBtnFinalizarCompra,
  );
  setColor(
    '--colorTagCarrinho',
    'text-color-input-tag-carrinho',
    data.colorEscassez,
  );
  setColor(
    '--bgColorTagCarrinho',
    'text-bgcolor-input-tag-carrinho',
    data.bgColorEscassez,
  );
  setColor('--colorInputRodape', 'text-color-input-rodape', data.colorRodape);
  setColor('--colorRelogio', 'text-color-input-relogio', data.colorRelogio);
  setColor(
    '--colorTextoOferta',
    'text-color-input-texto-oferta',
    data.colorTextoOferta,
  );
  setColor(
    '--colorTagDesconto',
    'text-color-input-tag-desconto',
    data.colorTagDesconto,
  );
  setColor(
    '--bgColorTagDesconto',
    'text-bgcolor-input-tag-desconto',
    data.backgroundColorTagDesconto,
  );
  setColor(
    '--bgColorInputRodape',
    'text-bgcolor-input-rodape',
    data.backgroundColorRodape,
  );

  setCheckbox('nome-loja', data.exibirNomeLoja);
  setCheckbox('formas-pagamento', data.exibirFormasPagamento);
  setCheckbox('input-cgc', data.exibirCgc);
  setCheckbox('input-exibir-email', data.exibirEmailContato);
  setCheckbox('input-exibir-endereco', data.exibirEndereco);
  setCheckbox('input-tag-carrinho', data.tagCarrinho);
  setCheckbox('input-cronometro', data.exibirCronometro);

  document.querySelector('#editor').value = data.mensagemTag;
  document.querySelector('#input-mensagem-tag').value = data.mensagemTag;

  if (data.exibirFormasPagamento)
    document.documentElement.style.setProperty(
      '--displayFormasPagamento',
      'block',
    );
  if (data.exibirCronometro) {
    document.documentElement.style.setProperty('--displayOferta', 'block');
    document.documentElement.style.setProperty(
      '--tempoCronometro',
      data.tempoCronometro,
    );
  }
  if (data.tagCarrinho) {
    document.documentElement.style.setProperty('--displayEscassez', 'block');
  }

  if (data.exibirEmailContato) {
    document.documentElement.style.setProperty('--displayEmailFooter', 'block');
  }

  if (data.exibirEndereco) {
    document.documentElement.style.setProperty(
      '--displayEnderecoFooter',
      'block',
    );
  }

  document.querySelector('.p-info-endereco').textContent = data.endereco;
  setInputText('input-text-email', data.email);
  setInputText('input-text-endereco', data.endereco);
  setInputText('input-text-cgc', data.cgc);
}

function customPreview(data) {
  document.documentElement.style.setProperty(
    '--alinhamentoLogo',
    data.alinhamento,
  );

  if (!data.exibirCarrinho) {
    document.querySelector('.body-cart-products').classList.add('hide');
    document
      .querySelector('.header-cart-products')
      .classList.add('hide-header');
  }

  if (data.exibirCgc) {
    document.querySelector('.p-info-cgc .p-info-num').textContent = formatCgc(
      data.cgc,
    );
    document.documentElement.style.setProperty('--displayCGCFooter', 'inline');
  }
  if (data.exibirNomeLoja) {
    document.querySelector('.p-info-cgc .p-info-nome').textContent =
      'VANILLA CHECKOUT ';
    document.documentElement.style.setProperty(
      '--displayNomeLojaFooter',
      'inline',
    );
  }

  if (data.exibirNomeLoja && data.exibirCgc)
    document.querySelector('.p-info-cgc .p-info-line').textContent = '-';

  if (data.exibirEmailContato)
    document.querySelector('.p-info-email').textContent = data.email;

  if (data.exibirEndereco)
    document.querySelector('.p-info-endereco').textContent = data.endereco;

  document.documentElement.style.setProperty('--textoAviso', data.textoAvisos);
}

function formatCgc(input) {
  // Remove caracteres não numéricos
  const cleaned = input.replace(/\D/g, '');

  if (cleaned.length === 11) {
    // Formatar como CPF: XXX.XXX.XXX-XX
    return (
      'CPF: ' + cleaned.replace(/(\d{3})(\d{3})(\d{3})(\d{2})/, '$1.$2.$3-$4')
    );
  } else if (cleaned.length === 14) {
    // Formatar como CNPJ: XX.XXX.XXX/XXXX-XX
    return (
      'CPNJ: ' +
      cleaned.replace(/(\d{2})(\d{3})(\d{3})(\d{4})(\d{2})/, '$1.$2.$3/$4-$5')
    );
  } else {
    throw new Error('A string fornecida deve conter 11 ou 14 dígitos.');
  }
}

function setColor(varCss, idInput, value) {
  document.documentElement.style.setProperty(varCss, value);
  document.getElementById(idInput).value = value.toUpperCase();
}

function setCheckbox(idInput, value) {
  if (value) {
    document.getElementById(idInput).parentElement.classList.add('checked');
    document.getElementById(idInput).setAttribute('checked', value);
  } else {
    document.getElementById(idInput).parentElement.classList.remove('checked');
    document.getElementById(idInput).removeAttribute('checked');
  }
}

function setInputText(idInput, value) {
  const input = document.getElementById(idInput);

  input.value = value;
}

function isHexColor(input) {
  let value = input.value;
  if (!value.startsWith('#')) value = '#' + value;
  const hexColorRegex = /^#([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$/;

  if (!hexColorRegex.test(value)) {
    input.parentElement.classList.add('error-input');
    input.value = '';
    document.documentElement.style.setProperty(input.dataset.color, '#FFFFFF');
  } else {
    input.parentElement.classList.remove('error-input');
    document.documentElement.style.setProperty(
      input.dataset.color,
      input.value,
    );
  }
}

const inputsTextColor = document.querySelectorAll('.input-text-color');

inputsTextColor.forEach((input) => {
  input.addEventListener('blur', () => {
    isHexColor(input);
  });
});

function openAlert(idAlert) {
  const alert = document.getElementById(idAlert);
  alert.classList.add('ativo');

  const barValue = alert.querySelector('.bar-value');
  let value = 100;
  setInterval(() => {
    if (value - 1 >= 0) value--;
    barValue.style.width = `${value}%`;
  }, 25);

  setTimeout(() => {
    alert.classList.remove('ativo');
  }, 3000);
}

const btnSalvar = document.querySelector('.btn-salvar');

btnSalvar.addEventListener('click', () => {
  const config = {
    alinhamento: getVarCss('--alinhamentoLogo'),
    backgroundColorBarraAvisos: getVarCss('--bgColorInputBarraAvisos'),
    backgroundColorBtnFinalizarCompra: getVarCss('--bgColorBotaoFinalizar'),
    backgroundColorBtnsEtapas: getVarCss('--bgColorBotoesEtapas'),
    colorBarraAvisos: getVarCss('--colorInputBarraAvisos'),
    colorBtnFinalizarCompra: getVarCss('--colorBotaoFinalizar'),
    colorBtnsEtapas: getVarCss('--colorBotoesEtapas'),
    colorEtapas: getVarCss('--colorEtapas'),
    colorTextoDesconto: getVarCss('--colorDesconto'),
    colorTextoTemporizador: getVarCss('--colorTemporizador'),
    exibirCarrinho:
      document.querySelector('#btn-status-cart span').textContent ==
      'Sempre aberto'
        ? true
        : false,
    exibirCgc: getCheckbox('input-cgc'),
    exibirEmailContato: getCheckbox('input-exibir-email'),
    exibirEndereco: getCheckbox('input-exibir-endereco'),
    exibirFormasPagamento: getCheckbox('formas-pagamento'),
    exibirNomeLoja: getCheckbox('nome-loja'),
    logo: '',
    textoAvisos: document.querySelector('#editor').innerHTML,
    cgc: getInputText('input-text-cgc'),
    email: getInputText('input-text-email'),
    endereco: getInputText('input-text-endereco'),
    colorTagDesconto: getVarCss('--colorTagDesconto'),
    backgroundColorTagDesconto: getVarCss('--bgColorTagDesconto'),
    colorTextoEscassez: getVarCss('--colorTextoEscassez'),
    colorRelogio: getVarCss('--colorRelogio'),
    exibirCronometro: getCheckbox('input-cronometro'),
    tempoCronometro: parseInt(
      document
        .querySelector('#btn-minutos-cronometro span')
        .textContent.replace(' minutos', ''),
    ),
    colorEscassez: getVarCss('--colorEscassez'),
    bgColorEscassez: getVarCss('--bgColorEscassez'),
    colorRodape: getVarCss('--colorInputRodape'),
    backgroundColorRodape: getVarCss('--bgColorInputRodape'),
    colorTextoOferta: getVarCss('--colorTextoOferta'),
    storeId: 1,
    mensagemTag: document.querySelector('#input-mensagem-tag').value,
  };

  saveData(config);
});

function getVarCss(variavel) {
  const root = document.documentElement;
  return getComputedStyle(root).getPropertyValue(variavel).trim();
}

function getCheckbox(idCheckbox) {
  return document.getElementById(idCheckbox).checked;
}

function getInputText(idInput) {
  return document.getElementById(idInput).value;
}

// CRONOMETRO

const minutesElement = document.getElementById('minutes');
const secondsElement = document.getElementById('seconds');

let totalMinutes = document.querySelector(
  '#btn-minutos-cronometro span',
).textContent;

let timeRemaining = parseInt(totalMinutes) * 60;

// Função para atualizar o cronômetro
function updateTimer() {
  // Calcular horas, minutos e segundos
  const minutes = Math.floor((timeRemaining % 3600) / 60);
  const seconds = timeRemaining % 60;

  // Atualizar os elementos HTML
  minutesElement.textContent = String(minutes).padStart(2, '0');
  secondsElement.textContent = String(seconds).padStart(2, '0');

  // Reduzir o tempo restante
  timeRemaining--;

  // Verificar se o cronômetro chegou a zero
  if (timeRemaining < 0) {
    clearInterval(timerInterval);
  }
}

// Atualizar o cronômetro a cada segundo
const timerInterval = setInterval(updateTimer, 1000);

// Inicializar o cronômetro
updateTimer();

const inputMensagemTag = document.querySelector('#input-mensagem-tag');

inputMensagemTag.addEventListener('input', () => {
  console.log(inputMensagemTag.value);
});

const inputsText = document.querySelectorAll('.input-text-info');

inputsText.forEach((input) => {
  input.addEventListener('input', () => {
    const pInfo = document.querySelector(`.${input.dataset.pinfo}`);

    pInfo.textContent = input.value;

    if (input.id === 'input-text-cgc') {
      pInfo.textContent = formatCgc(input.value);
    }
  });
});

const nomeLoja = document.querySelector('#nome-loja');

nomeLoja.addEventListener('change', () => {
  let display;
  display = nomeLoja.checked ? 'inline' : 'none';
  document.documentElement.style.setProperty(
    '--displayNomeLojaFooter',
    display,
  );
});

const inputCgc = document.querySelector('#input-cgc');

inputCgc.addEventListener('change', () => {
  let display;
  display = inputCgc.checked ? 'inline' : 'none';
  document.documentElement.style.setProperty('--displayCGCFooter', display);

  // document.querySelector('.p-info-num').textContent = formatCgc(document.querySelector('#input-text-cgc').value);
});

const formasPagamento = document.querySelector('#formas-pagamento');

formasPagamento.addEventListener('change', () => {
  let display;
  display = formasPagamento.checked ? 'block' : 'none';
  document.documentElement.style.setProperty(
    '--displayFormasPagamento',
    display,
  );
});

const inputExibirEmail = document.querySelector('#input-exibir-email');

inputExibirEmail.addEventListener('change', () => {
  let display;
  display = inputExibirEmail.checked ? 'block' : 'none';
  document.documentElement.style.setProperty('--displayEmailFooter', display);
});

const inputExibirEndereco = document.querySelector('#input-exibir-endereco');

inputExibirEndereco.addEventListener('change', () => {
  let display;
  display = inputExibirEndereco.checked ? 'block' : 'none';
  document.documentElement.style.setProperty(
    '--displayEnderecoFooter',
    display,
  );
});

const tagCarrinho = document.querySelector('#input-tag-carrinho');

tagCarrinho.addEventListener('change', () => {
  let display;
  display = tagCarrinho.checked ? 'block' : 'none';
  document.documentElement.style.setProperty('--displayEscassez', display);
});
